import typescript from '@rollup/plugin-typescript';
import del from 'rollup-plugin-delete';
import copy from 'rollup-plugin-copy';
import generatePackageJson from 'rollup-plugin-generate-package-json';
import terser from '@rollup/plugin-terser';
import dts from 'rollup-plugin-dts';
import svgo from 'rollup-plugin-svgo';
import resolve from '@rollup/plugin-node-resolve';
import commonjs from '@rollup/plugin-commonjs';
import pkg from './package.json' assert { type: "json" };

const outputDir = './library/';

export default [
  {
    input: ['./src/index.ts'],
    output: {
      dir: './internal/'
    },
    plugins: [
      del({ targets: ['internal/*', 'library/*'] }),
      typescript({
        declaration: true,
        outDir: './internal/',
        rootDir: './src/',
        exclude: ['./example/**/*', './internal/**/*', './library/**/*']
      }),
      resolve(), // Resolve modules from node_modules
      commonjs(), // Convert CommonJS modules to ES modules
      svgo()
    ]
  },
  {
    input: "./internal/index.d.ts",
    output: [{ file: "./library/ss_annotator.d.ts", format: "es" }],
    plugins: [dts()],
  },
  {
    input: ['src/index.ts'],
    output: [
      {
        file: outputDir + pkg.module,
        format: 'es',
        sourcemap: true
      },
      {
        file: outputDir + pkg.main,
        name: 'ss_annotator',
        format: 'umd',
        sourcemap: true
      }
    ],
    plugins: [
      generatePackageJson({
        baseContents: (pkg) => {
          pkg.scripts = {};
          pkg.dependencies = {};
          pkg.devDependencies = {};
          return pkg;
        }
      }),
      typescript(),
      resolve(), // Resolve modules from node_modules
      commonjs(), // Convert CommonJS modules to ES modules
      svgo(),
      terser(),
      copy({
        targets: [{
          src: 'package.json', dest: 'library'
        }, {
          src: 'LICENSE', dest: 'library'
        },]
      }),
      del({ targets: ['internal/*'] })
    ]
  }
];
