import Icon from './ellipse-frame-marker-icon.svg';
import { Settings } from '../../base/Settings';
import { RectangleAnnotatorState } from '../RectangleAnnotatorState';
import { ToolboxPanel } from '../../toolbars/ToolboxPanel';
import { EllipseAnnotator } from '../ellipse-annotation/EllipseAnnotator';

export class EllipseFrameAnnotator extends EllipseAnnotator {
  /**
   * String type name of the marker type. 
   * 
   * Used when adding {@link AnnotatorArea.availableAnnotatorTypes} via a string and to save and restore state.
   */
  public static typeName = 'EllipseFrameAnnotator';
  /**
   * Annotator type title (display name) used for accessibility and other attributes.
   */
  public static title = 'Ellipse frame marker';
  /**
   * SVG icon markup displayed on toolbar buttons.
   */
  public static icon = Icon;

  /**
   * Creates a new marker.
   *
   * @param container - SVG container to hold marker's visual.
   * @param overlayContainer - overlay HTML container to hold additional overlay elements while editing.
   * @param settings - settings object containing default markers settings.
   */
  constructor(container: SVGGElement, overlayContainer: HTMLDivElement, settings: Settings) {
    super(container, overlayContainer, settings);

    // reset colors so 'transparent' is excluded
    this.strokePanel.colors= settings.defaultColorSet;

    this.fillColor = 'transparent';
  }

  /**
   * Returns the list of toolbox panels for this marker type.
   */
  public get toolboxPanels(): ToolboxPanel[] {
    return [this.strokePanel, this.strokeWidthPanel, this.strokeStylePanel];
  }

  /**
   * Returns current marker state that can be restored in the future.
   */
  public getState(): RectangleAnnotatorState {
    const result = super.getState();
    result.typeName = EllipseFrameAnnotator.typeName;
    return result;
  }
}
